 %------------------------------------------------------------------
 %    
 %    
 %    The quadradtic operator Q
 %
 function [Q] = Q(obj,U,V)
 
  H=obj.H;           % Number of harmonics
  Neq=obj.Neq;       % Number of equations
  
  indc=[Neq+1  :2*Neq:Neq*(2*H-1)+1];     % index of  uic 
  inds=[2*Neq+1:2*Neq:Neq*(2*H)+1  ];     % index of  uis 

  
  Q=zeros(Neq*(2*H+1)+1,1);
  
 
  %------------------------------------------------------------------------------
  %     Q(U,V) depends on pQ(.,.)   lambda pL1(.) and  omega pM(.)   see annexe 1
  %------------------------------------------------------------------------------
  
  % Harmonic zero
   SOM=zeros(Neq,1);
   for j=1:H
      SOM=SOM+pQ(U(indc(j):indc(j)+Neq-1),V(indc(j):indc(j)+Neq-1))  ...
             +pQ(U(inds(j):inds(j)+Neq-1),V(inds(j):inds(j)+Neq-1));
   end
   Q(1:Neq)= 0.5*SOM + pQ(U(1:Neq),V(1:Neq))      ...      %   Q(U,V)
                     + V(Neq*(2*H+1)+1)*pL1(U(1:Neq));      %  lambda.L1(U)
  
  % Harmonics 1,2,3, ...
  for ih=1:H   
     SOMC=zeros(Neq,1);
     SOMS=zeros(Neq,1);
     
     % ++++++ 
     
        for j=1:ih-1
          SOMC=SOMC+pQ(U(indc(ih-j):indc(ih-j)+Neq-1),V(indc(j):indc(j)+Neq-1))  ...
                   -pQ(U(inds(ih-j):inds(ih-j)+Neq-1),V(inds(j):inds(j)+Neq-1));
          
          SOMS=SOMS+pQ(U(indc(ih-j):indc(ih-j)+Neq-1),V(inds(j):inds(j)+Neq-1))  ...
                   +pQ(U(inds(ih-j):inds(ih-j)+Neq-1),V(indc(j):indc(j)+Neq-1));
        end
     
     % --------
   
         for j=ih+1:H
            SOMC=SOMC+pQ(U(indc(j):indc(j)+Neq-1),V(indc(j-ih):indc(j-ih)+Neq-1))     ...
                     +pQ(U(inds(j):inds(j)+Neq-1),V(inds(j-ih):inds(j-ih)+Neq-1))     ...   
                                                                                      ...
                     +pQ(U(indc(j-ih):indc(j-ih)+Neq-1),V(indc(j):indc(j)+Neq-1))     ...
                     +pQ(U(inds(j-ih):inds(j-ih)+Neq-1),V(inds(j):inds(j)+Neq-1));
                 
            SOMS=SOMS+pQ(U(inds(j):inds(j)+Neq-1),V(indc(j-ih):indc(j-ih)+Neq-1))     ...
                     -pQ(U(indc(j):indc(j)+Neq-1),V(inds(j-ih):inds(j-ih)+Neq-1))     ...   
                                                                                      ...
                     -pQ(U(inds(j-ih):inds(j-ih)+Neq-1),V(indc(j):indc(j)+Neq-1))     ...
                     +pQ(U(indc(j-ih):indc(j-ih)+Neq-1),V(inds(j):inds(j)+Neq-1));                           
                     
         end   
      % 
         Q(indc(ih):indc(ih)+Neq-1)=0.5*SOMC + pQ(U(indc(ih):indc(ih)+Neq-1),V(1:Neq))   ...         % Q(U,V)
                                             + pQ(U(1:Neq),V(indc(ih):indc(ih)+Neq-1))    ...        %
                                             + V(Neq*(2*H+1)+1)*pL1(U(indc(ih):indc(ih)+Neq-1)) ...  %  lambda.L1(U)
                                             - ih*V(Neq*(2*H+1)+2)*pM(U(inds(ih):inds(ih)+Neq-1)) ;  %  - omega.M(U)
                                             
                                             
         Q(inds(ih):inds(ih)+Neq-1)=0.5*SOMS + pQ(U(inds(ih):inds(ih)+Neq-1),V(1:Neq))   ...         % Q(U,V)
                                             + pQ(U(1:Neq),V(inds(ih):inds(ih)+Neq-1))    ...        %
                                             + V(Neq*(2*H+1)+1)*pL1(U(inds(ih):inds(ih)+Neq-1))  ... %  lambda.L1(U)
                                             + ih*V(Neq*(2*H+1)+2)*pM(U(indc(ih):indc(ih)+Neq-1));   %  - omega.M(U)
   end   
 
  
  
  %------------------------------------------------------------------------------ 
  %   ---     Phase   equation        ---
  %------------------------------------------------------------------------------

  Q(Neq*(2*H+1)+1)= 0 ; 
 
 end  
 %------------------------------------------------------------------
 %    
 %     DEUXRES    model
 
 function [pQ] = pQ(U,V)

  pQ=zeros(6,1);
  
  pQ(3)=-U(1)*(V(5)+V(6));
  pQ(4)=-U(2)*(V(5)+V(6));
  pQ(5)=-0.5*(U(1)*V(1) + U(2)*V(2));
  pQ(6)=-    (U(1)*V(1) + U(2)*V(2));
  
 end
 
 function [pL1] = pL1(U)

  pL1=zeros(6,1);
  
  pL1(3)=-U(3);
  pL1(4)=-U(4);
  
 end
 
 function [pM] = pM(U)

  pM=zeros(6,1);
  
  pM(1)=U(1);
  pM(2)=U(2);
  pM(3)=U(3);
  pM(4)=U(4);
  
 end
 
  
