% --------------------------------------------------------------------------
%  periodic solutions of forced Duffing model by HBM with MANLAB
%  -------------------------------------------------------------------------
%
%   Model equation
%   --------------
%   u'' + 2*mu u' + u + u^3 =  F cos(lambda t)  
%
%    u(t) unknown, lambda real parameter. 
%
%    we put   v = u'
%             w = u^2
%           
%   then
%
%     u'  =                     v
%     v'  = Fcos(lambda t)   -u -2*mu v    - uw   
%     0   =                     w        - u^2
%             
%   
%    With  Z(t) = [ u , v , w  ]  (Neq=3) the system becomes
%  
%    m(Z') = c(lambda,t)  + l0(Z)  + q(Z,Z) 
%
%  
%  Harmonic balance
%  ----------------
%  we put lamnda = omega  
%
%  Z(t) = Z0 + Z1c cos(omega t) + Z1s sin(omega t) + Z2c cos(2 Omega t) + Z2s sin(2 Omega t) + ... 
%              ...  + ZHc cos(H omega t) + ZHs sin(H omega t).
%
%  the balance of the harmonics leads to a large system of size  Neq*(2H+1)
%
%      C0    +   L0(U)   + Q(U,U) - omega M(U)= 0 
%                  
%
%     with    U=[Z0  Z1c Z1s  Z2c Z2s  ...  ZHs ]
% 
%    no phase condition
%
%  Final algebraic system for Manlab  bL0 + bL(bU) + bQ(bU,bU) =0 
%  --------------------------------------------------------------
%
%   bU = [ U , omega ]
%
%   bL0       = C0
%   bL(bu)    = L0(U) + lambda C1
%   bQ(bU,bU) = Q(U,U) + lambda L1(U) - omega M(U)
%
%
%--------------------------------------------------------------------------

 manlabinit;
 
 H=5;
 Neq=3;
 
 F=1          % forcing amplitude
 mu=0.05      % damping factor
 alpha=1      % nonlinear term coefficient
 
 ML_problem  = DUFFO(H,Neq,F,mu,alpha);      
 
 u0=[0 0 0  ];
 
 % starting point (for H=9)
 %ML_Ustart   = [  u0 ,u0 ,u0 , u0 ,u0 ,u0,u0,u0,u0,u0,u0, u0 ,u0 ,u0,u0,u0,u0,u0,u0,      0  ]';  
 
 % starting point (for H=5)
 %ML_Ustart   = [  u0 ,u0 ,u0 , u0 ,u0 ,u0,u0,u0,u0,u0,u0,        0  ]';
 
 
 ML_Ustart   = [  u0 ,u0 ,u0 , u0 ,u0 ,u0,u0,u0,u0,u0,u0,        1.4  ]';
 
 %starting point on mode 1
 %ML_Ustart   = [  0 0 0.125 , 0.5 0 0 , 0 -0.5 0 , u0 ,u0 ,u0,u0,u0,u0,u0,u0, 1.1  ]';
 
  %  index of variables for the bifurcation diagram
 ML_dispvars = [  (2*H+1)*Neq+1  4 ; (2*H+1)*Neq+1  7 ; (2*H+1)*Neq+1  16 ; (2*H+1)*Neq+1  19   ;];   
                                                      
 ML_pointdisplay=1;
 
 ML_globaldisplay=1;

 manlabstart; 


